==> haskell-getopt-generics-0.13.1.0-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 getopt-generics
version:              0.13.1.0
visibility:           public
id:                   getopt-generics-0.13.1.0-4xvit3T6dg8AuILgQcnWis
key:                  getopt-generics-0.13.1.0-4xvit3T6dg8AuILgQcnWis
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  712d75d429ffb615f8ebe9f73ffd651c
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.1.0-4xvit3T6dg8AuILgQcnWis
depends:
    base-4.17.2.1 base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    base-orphans-0.9.3-Ea0QDvAHmuuDwawVVeTKOO
    generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-getopt-generics-0.13.1.0-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-getopt-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 getopt-generics
version:              0.13.1.0
visibility:           public
id:                   getopt-generics-0.13.1.0-3voArd58OtaNSFvDzVJiV
key:                  getopt-generics-0.13.1.0-3voArd58OtaNSFvDzVJiV
license:              BSD-3-Clause
copyright:            Zalora South East Asia Pte Ltd
maintainer:           linh.nguyen@zalora.com, soenkehahn@gmail.com
author:               Linh Nguyen, Sönke Hahn
homepage:             https://github.com/soenkehahn/getopt-generics#readme
synopsis:             Create command line interfaces with ease
description:          Create command line interfaces with ease
category:             Console, System
abi:                  2426221e56ffabfecdfd6278dbe277fd
exposed:              True
exposed-modules:      WithCli WithCli.Pure
hidden-modules:
    WithCli.Argument WithCli.Flag WithCli.HasArguments WithCli.Modifier
    WithCli.Modifier.Types WithCli.Normalize WithCli.Parser
    WithCli.Pure.Internal WithCli.Result Paths_getopt_generics

import-dirs:          /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/getopt-generics-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-getopt-generics
hs-libraries:         HSgetopt-generics-0.13.1.0-3voArd58OtaNSFvDzVJiV
depends:
    base-4.17.2.1 base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    base-orphans-0.9.3-JT0HAQbbOJV5hOgWUnXcwi
    generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C

haddock-interfaces:
    /usr/share/doc/haskell-getopt-generics/html/getopt-generics.haddock

haddock-html:         /usr/share/doc/haskell-getopt-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
